@@ -1,10 +1,8 @@
 from pathlib import Path
 from tsdoc0.python.segment import Segment
 from tsdoc0.python.utils import repr_parent
-from typing import Dict
 from typing import Final
 from typing import Optional
-from typing import Tuple
 from typing import TYPE_CHECKING
 
 # Conditional import used because there would be a circular dependency
@@ -16,19 +14,19 @@ import attr
 import csv
 
 with open(Path(__file__, "..", "vocabulary_terms.csv").resolve()) as csvfile:
-    _DICTIONARY: Final[Tuple[Dict[str, str], ...]] = tuple(
+    _DICTIONARY: Final[tuple[dict[str, str], ...]] = tuple(
         row for row in csv.DictReader(csvfile, strict=True)
     )
 
-_NAMES: Final[Dict[str, str]] = {
+_NAMES: Final[dict[str, str]] = {
     row["text"]: row["name"] for row in _DICTIONARY if len(row["name"]) > 0
 }
 
-_DEFINITIONS: Final[Dict[str, str]] = {
+_DEFINITIONS: Final[dict[str, str]] = {
     row["text"]: row["definition"] for row in _DICTIONARY
 }
 
-_INSTRUCTIONS: Final[Dict[str, str]] = {
+_INSTRUCTIONS: Final[dict[str, str]] = {
     row["text"]: row["instruction"] for row in _DICTIONARY
 }
 
